==> wikindx3_2_2.tar.gz: wikindx3/core/browse/BROWSEPUBLISHER.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2005
sirfragalot@users.sourceforge.net

**********************************************************************************/
/*****
* BROWSEPUBLISHER class
*
* Browse publishers as a 'tag cloud'
*
* 
$Header: /cvsroot/wikindx/wikindx3/core/browse/BROWSEPUBLISHER.php,v 1.4 2005/12/20 07:36:22 sirfragalot Exp $
*****/
class BROWSEPUBLISHER
{
// Constructor
	function BROWSEPUBLISHER($db)
	{
		$this->db = $db;
		include_once("core/html/MISC.php");
		include_once("core/html/HTML.php");
		$this->html = new HTML();
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		include_once("core/browse/BROWSECOMMON.php");
		$this->common = new BROWSECOMMON($this->db);
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
	}
// display publishers
	function display()
	{
		$this->template->setVar('heading', $this->messages->text("heading", "browsePublisher"));
		$this->sum = $this->publisher = array();
		$this->getPublishers();
		if(empty($this->publisher))
		{
			$pString = MISC::p("&nbsp;") . $this->messages->text("misc", "noPublishers");
			$this->template->setVar('body', $pString);
			return $this->template->process();
		}
		asort($this->sum);
		asort($this->publisher);
		$pString = MISC::p($this->bib, "hint") . 
			MISC::pBrowse($this->process(), "center");
		$this->template->setVar('body', $pString);
		return $this->template->process();
	}
// Process and display results
	function process()
	{
		$lowestSum = current($this->sum);
		$highestSum = end($this->sum);
		foreach($this->publisher as $id => $name)
		{
//			$name = str_replace(' ', "&nbsp;", $name);
			$name = $this->html->codeToHtml($name);
			list($red, $colour) = $this->common->colourText($lowestSum, $highestSum, $this->sum[$id]);
			$size = $this->common->sizeText($lowestSum, $highestSum, $red);
			$links[] = MISC::aBrowse($colour, $size, $name, "index.php?action=listPublisherProcess" . 
			htmlentities("&id=" . $id)) . "&nbsp;[" . $this->sum[$id] . "]";
		}
		return join("&nbsp; ", $links);
	}
// Get publishers from db
	function getPublishers()
	{
		list($condition, $bib) = $this->common->userBibCondition('WKX_resource_misc');
		if($condition)
			$condition = " WHERE " . $condition;
		$recordset = $this->db->select(array('WKX_resource_misc'), array('id', 'publisher'), $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->collate($row);
		if($bib)
			$this->bib = $this->messages->text("user", "bibliography") . ": " . $bib;
		else if($this->session->getVar('setup_multiUser'))
			$this->bib = $this->messages->text("user", "bibliography") . ": " . 
				$this->messages->text("user", "masterBib");
	}
// Add publishers to array and sum totals
	function collate($row)
	{
		if(!$row['publisher'])
			return FALSE;
		if(!array_key_exists($row['publisher'], $this->sum))
			$this->sum[$row['publisher']] = 1;
		else
			++$this->sum[$row['publisher']];
		$publishersCondition = "'" . $row['publisher'] . "'";
		$condition = $this->db->formatField('id') . "=" . $publishersCondition;
		$recordset = $this->db->select(array('WKX_publisher'), 
			array("id", "publisherName", "publisherLocation"), 
			" WHERE " . $condition);
		while($row = $this->db->loopRecordSet($recordset))
		{
			if(array_key_exists('publisherName', $row) && array_key_exists('publisherLocation', $row) 
				&& $row['publisherName'] && $row['publisherLocation'])
				$this->publisher[$row['id']] = stripslashes($row['publisherName']) . 
				"&nbsp;(" . stripslashes($row['publisherLocation']) . ")";
			else if(array_key_exists('publisherLocation', $row) && $row['publisherLocation'])
				$this->publisher[$row['id']] = "(" . stripslashes($row['publisherLocation']) . ")";
			else
				$this->publisher[$row['id']] = stripslashes($row['publisherName']);
		}
	}
}
?>

==> wikindx3_3_1.tar.gz: wikindx3/core/browse/BROWSEPUBLISHER.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2006
sirfragalot@users.sourceforge.net

**********************************************************************************/
/*****
* BROWSEPUBLISHER class
*
* Browse publishers as a 'tag cloud'
*
* 
$Header: /cvsroot/wikindx/wikindx3/core/browse/BROWSEPUBLISHER.php,v 1.7 2006/04/29 00:44:46 sirfragalot Exp $
*****/
class BROWSEPUBLISHER
{
// Constructor
	function BROWSEPUBLISHER($db, $vars)
	{
		$this->db = $db;
		$this->vars = $vars;
		include_once("core/html/MISC.php");
		include_once("core/html/HTML.php");
		$this->html = new HTML();
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		include_once("core/browse/BROWSECOMMON.php");
		$this->common = new BROWSECOMMON($this->db);
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
	}
// display publishers
	function display()
	{
		$this->template->setVar('heading', $this->messages->text("heading", "browsePublisher"));
		$this->sum = $this->publisher = array();
		$this->getPublishers();
		if(empty($this->publisher))
		{
			$pString = MISC::p("&nbsp;") . $this->messages->text("misc", "noPublishers");
			$this->template->setVar('body', $pString);
			return $this->template->process();
		}
		natcasesort($this->sum);
		natcasesort($this->publisher);
		$this->publisher = $this->common->paging($this->vars, $this->publisher);
		$pString = MISC::p($this->bib, "hint") . $this->common->linksInfo() . 
			MISC::pBrowse($this->process(), "center");
		$this->template->setVar('body', $pString);
		$this->template->setVar('paging', $this->common->pagingLinks("action=browsePublisher"));
		return $this->template->process();
	}
// Process and display results
	function process()
	{
		$lowestSum = current($this->sum);
		$highestSum = end($this->sum);
		foreach($this->publisher as $id => $name)
		{
//			$name = str_replace(' ', "&nbsp;", $name);
			$name = $this->html->codeToHtml($name);
			list($red, $colour) = $this->common->colourText($lowestSum, $highestSum, $this->sum[$id]);
			$size = $this->common->sizeText($lowestSum, $highestSum, $red);
			$links[] = MISC::aBrowse($colour, $size, $name, "index.php?action=listPublisherProcess" . 
			htmlentities("&id=" . $id)) . "&nbsp;[" . $this->sum[$id] . "]";
		}
		return join("&nbsp; ", $links);
	}
// Get publishers from db
	function getPublishers()
	{
		list($condition, $bib) = $this->common->userBibCondition('WKX_resource_misc');
		if($condition)
			$condition = " WHERE " . $condition;
		$recordset = $this->db->select(array('WKX_resource_misc'), array('id', 'publisher'), $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->collate($row);
		if($bib)
			$this->bib = $this->messages->text("user", "bibliography") . ": " . $bib;
		else if($this->session->getVar('setup_multiUser'))
			$this->bib = $this->messages->text("user", "bibliography") . ": " . 
				$this->messages->text("user", "masterBib");
	}
// Add publishers to array and sum totals
	function collate($row)
	{
		if(!$row['publisher'])
			return FALSE;
		if(!array_key_exists($row['publisher'], $this->sum))
			$this->sum[$row['publisher']] = 1;
		else
			++$this->sum[$row['publisher']];
		$publishersCondition = "'" . $row['publisher'] . "'";
		$condition = $this->db->formatField('id') . "=" . $publishersCondition;
		$recordset = $this->db->select(array('WKX_publisher'), 
			array("id", "publisherName", "publisherLocation"), 
			" WHERE " . $condition);
		while($row = $this->db->loopRecordSet($recordset))
		{
			if(array_key_exists('publisherName', $row) && array_key_exists('publisherLocation', $row) 
				&& $row['publisherName'] && $row['publisherLocation'])
				$this->publisher[$row['id']] = stripslashes($row['publisherName']) . 
				"&nbsp;(" . stripslashes($row['publisherLocation']) . ")";
			else if(array_key_exists('publisherLocation', $row) && $row['publisherLocation'])
				$this->publisher[$row['id']] = "(" . stripslashes($row['publisherLocation']) . ")";
			else
				$this->publisher[$row['id']] = preg_replace("/{(.*)}/U", "$1", 
				stripslashes($row['publisherName']));
		}
	}
}
?>
